#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of ROBOTGAME
#
# ROBOTGAME is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# ROBOTGAME is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# ROBOTGAME.  If not, see <http://www.gnu.org/licenses/>.
#
# ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' '
#
#                         level3.py
#                     --------------------
#       date created : Wed Aug 8 2012
#          copyright : (C) 2012 Niels G. W. Serup
#      maintained by : Niels G. W. Serup <ns@metanohi.name>

"""
The third level.
"""

import os
import pygame
import random
import re

import level
import player
import tile
import block
import boulder
import lever


import logic.colourboxes

class Level3(level.Level):
    def __init__(self, game, graphics_dir, paused=False):
        level.Level.__init__(self, game, graphics_dir, size=(64*20, 48*20),
                             paused=paused)

        self.dimensions = 20, 20

        for i in range(self.dimensions[0]):
            for j in range(self.dimensions[1]):
                self.tiles.append(
                    tile.Tile(self, i*64, j*48, self.imgs['ground1']))

        self.draw_background()


    def load(self):
        """Load all resources used in the level."""
        tile_list = ['ground1', 'ground2']

        for tile in tile_list:
            self.imgs[tile] = pygame.image.load(os.path.join(
                    self.graphics_dir, 'tiles', '%s.png' % tile))

        block_list = ['block1']
        for block in block_list:
            self.imgs[block] = pygame.image.load(os.path.join(
                    self.graphics_dir, 'blocks', '%s.png' % block))

    def restart(self):
        for obj in self.objects:
            obj.reset_pos()
